@@ -3,8 +3,7 @@ package Bundle::Siebel::MonitoringTools;
 use 5.008009;
 use strict;
 use warnings;
-
-our $VERSION = 0.06;
+our $VERSION = '0.07'; # VERSION
 
 1;
 __END__
@@ -63,6 +62,8 @@ None by default.
     RPC::XML [0.78]
     CHI [0.58]
     TryCatch [1.003002]
+    Dist::Zilla::Plugin::CheckExtraTests [0.029]
+    Try::Tiny [0.27]
 
 =head1 SEE ALSO
 
